#!/bin/bash
#-------------------------------------------------------
# file:         get_alarm_lld.sh
# comment:      Obtem os eventos registrados para cada componente citado no arquivo de alarmes 
# author:       Aecio Pires <aeciopires@gmail.com>
# date:         09-fev-2015
# revision:     Aecio Pires <aecio@dynavideo.com.br>
# Last updated: 09-fev-2015, 12:03
#-------------------------------------------------------

# Para saber mais sobre como usar o recurso LLD do Zabbix, consulte os links abaixo:

#[1] http://andredeo.blogspot.com.br/2014/11/lld-no-zabbix-com-shell-script.html
#[2] http://spinola.net.br/blog/?p=402
#[3] https://www.zabbix.com/documentation/3.0/manual/discovery/low_level_discovery

################################################################
# Funcoes Especificas
################################################################

#----------------------------------------------------
# Informa o modo correto de usar o script
usage() {

	echo ""
        echo "Help:"
        echo "$CMDLINE TIPO_CONSULTA CAMINHO_ARQUIVO_ALARME"
        echo ""
        echo "Onde:"
        echo ""
        echo "TIPO_CONSULTA=> Por enquanto so pode ser LLD (Low-level Discovery), que gera o resultado no formato JSON para ser lido pelo Zabbix."
        echo "CAMINHO_ARQUIVO_ALARME=> Caminho do arquivo com alarmes a serem lidos."
        echo ""
        echo "Exemplos de execucao:"
        echo ""
        echo "$CMDLINE LDD /tmp/alarm_zabbix.log"
        echo ""
        echo "OBS.: O arquivo usado neste exemplo possui varias linhas, onde cada uma delas possui 8 campos de informacoes separados por ',' ."
        echo "Exemplo de uma linha desse arquivo."
        echo "ID,DATA,HOST_TYPE,HOSTNAME,COMPONENT,EVENT,SEVERITY,MESSAGE"
        echo "1422649972,2014-01-25_17:32:52,SWITCH,switch-01,INTERFACE_WEB,STARTED,INFO,A interface web do switch-01 foi inicada. O equipamento foi reiniciado?"
}


#Definicao de variaveis
CMDLINE=$0
TYPE_SEARCH=$1
FILE_ALARM=$2
COMPONENTE=$3
EVENTO=$4
ID=$5


# Checa os parametros passados ao script
if [ "$#" -eq "0" ] ; then
        echo "[ERRO] Faltou voce informar os parametros obrigatorios. Veja o help do script abaixo."
	usage
        ERRO=3
        exit $ERRO
fi

if [ -z $FILE_ALARM ]; then
        echo "[ERRO] Voce nao informou o caminho completo em que esta o arquivo de alarmes."
        ERRO=3
        exit $ERRO
fi

case $TYPE_SEARCH in
	LLD)
		#Este trecho de codigo le cada linha do arquivo, cujo os campos estao separados por "," , e faz a conversao para o formato JSON homologado
		#no site http://jsonlint.com/
		echo -e "{"
		echo -e "\t\"data\":[\n"
		cat "$FILE_ALARM" | awk -F, '{print "{\"{#ID}\": \""$1"\", \"{#COMPONENT}\": \""$5"\", \"{#EVENT}\":\""$6"\", \"{#MESSAGE}\":\""$8"\", \"{#DATA}\": \""$2"\", \"{#HOST_TYPE}\": \""$3"\", \"{#HOSTNAME}\": \""$4"\", \"{#SEVERITY}\": \""$7"\", \"{#ALL}\":\""$0"\" },"}' | grep -w "$COMPONENTE" | grep -w "$EVENTO" | sed ':a;$!{N;ba;};s/\(.*\),/\1\ /'
		echo -e "\t]" 
		echo -e "}\n" 

	;;
        *)
                echo "[ERRO] Tipo de busca: $TYPE_SEARCH nao suportada."
		ERRO=1
		exit $ERRO
        ;;
esac
